AdminLTE 3 | Advanced form elements

# Advanced Form

### Select2 (Default Theme)

Minimal
Disabled
Multiple
Disabled Result

##### Custom Color Variants

Minimal (.select2-danger)
Multiple (.select2-purple)

### Select2 (Bootstrap4 Theme)

Minimal
Disabled
Multiple
Disabled Result

### Bootstrap Duallistbox

Multiple

### Input masks

Date masks:
US phone mask:
Intl US phone mask:
IP mask:

### Color & Time Picker

Color picker:
Color picker with addon:
Time picker:

### Date picker

Date:
Date and time:
Date range:
Date and time range:
Date range button:

### iCheck Bootstrap - Checkbox & Radio Inputs

Primary checkbox
Primary radio
Danger checkbox
Danger radio
Success checkbox
Success radio

### Bootstrap Switch

### bs-stepper

Email address
Password
File input
Choose file
Upload

### Dropzone.js jQuery File Upload like look

Add files

()